@@ -4,6 +4,8 @@ describe 'manila::db::sync' do
 
   shared_examples_for 'manila-dbsync' do
 
+    it { is_expected.to contain_class('manila::deps') }
+
     it 'runs manila-db-sync' do
       is_expected.to contain_exec('manila-manage db_sync').with(
         :command     => 'manila-manage db sync',
@@ -12,7 +14,12 @@ describe 'manila::db::sync' do
         :user        => 'manila',
         :try_sleep   => 5,
         :tries       => 10,
-        :logoutput   => 'on_failure'
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[manila::install::end]',
+                         'Anchor[manila::config::end]',
+                         'Anchor[manila::dbsync::begin]'],
+        :notify      => 'Anchor[manila::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
